@@ -1,5 +1,5 @@
 #
-# $Id: Packet.pm,v 1.2.2.7 2006/10/04 21:18:37 gomor Exp $
+# $Id: Packet.pm,v 1.2.2.9 2006/11/04 12:17:11 gomor Exp $
 #
 package Net::Packet;
 use strict;
@@ -7,7 +7,7 @@ use warnings;
 
 require v5.6.1;
 
-our $VERSION = '3.00_02';
+our $VERSION = '3.01';
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -58,6 +58,81 @@ __END__
 
 Net::Packet - a framework to easily send and receive frames from layer 2 to layer 7
 
+=head1 SYNOPSIS
+
+   #Load all modules, it also initializes a Net::Packet::Env object, 
+   # and imports all utility subs and constants in current namespace
+   # WARNING: this is not the prefered way to use Net::Packet
+   use Net::Packet;
+
+   #Build IPv4 header
+   my $ip = Net::Packet::IPv4->new(dst => '192.168.0.1');
+
+   #Build TCP header
+   my $tcp = Net::Packet::TCP->new(dst => 22);
+
+   #Assamble frame,it will also open a Net::Packet::DescL3 descriptor
+   # and a Net::Packet::Dump object
+   my $frame = Net::Packet::Frame->new(l3 => $ip, l4 => $tcp);
+
+   $frame->send;
+
+   #Print the reply just when it has been received
+   until ($Env->dump->timeout) {
+      if ($frame->recv) {
+         print $frame->reply->l3, "\n";
+         print $frame->reply->l4, "\n";
+         last;
+      }
+   }
+
+   # Alternative way of using Net::Packet, which is the recommanded way
+   # First thing to do, get a default Env object. It will contain all 
+   # information regarding your default interface setup and some 
+   # specific options regarding Net::Packet framework behaviour
+   use Net::Packet::Env qw($Env);
+
+   # Then, load modules you need to accomplish your work
+   require Net::Packet::DescL3;
+   require Net::Packet::Dump;
+   require Net::Packet::Frame;
+   require Net::Packet::IPv4;
+   require Net::Packet::TCP;
+
+   # We manually create Desc and Dump objects to have complete control 
+   # on Net::Packet framework behaviour
+   my $desc = Net::Packet::DescL3->new(
+      target => '192.168.0.1',
+   );
+
+   my $dump = Net::Packet::Dump->new(
+      filter        => 'tcp',
+      keepTimestamp => 1,
+   );
+   $dump->start;
+
+   #Build IPv4 header
+   my $ip = Net::Packet::IPv4->new(dst => '192.168.0.1');
+
+   #Build TCP header
+   my $tcp = Net::Packet::TCP->new(dst => 22);
+
+   #Assamble frame. Because we have created Desc and Dump objects, 
+   # they will not be automatically created here
+   my $frame = Net::Packet::Frame->new(l3 => $ip, l4 => $tcp);
+   $frame->send;
+
+   until ($dump->timeout) {
+      if ($frame->recv) {
+         print $frame->reply->l3, "\n";
+         print $frame->reply->l4, "\n";
+         last;
+      }
+   }
+
+   $dump->stop;
+   $dump->clean;
+
 =head1 CLASS HIERARCHY
 
   Net::Packet
@@ -110,41 +185,13 @@ Net::Packet - a framework to easily send and receive frames from layer 2 to laye
      |
      +---Net::Packet::Layer7
 
-=head1 SYNOPSIS
-
-   #Load all modules, it also initializes a Net::Packet::Env object, 
-   # and imports all utility subs and constances in current namespace
-   use Net::Packet;
-
-   #Build IPv4 header
-   my $ip = Net::Packet::IPv4->new(dst => '192.168.0.1');
-
-   #Build TCP header
-   my $tcp = Net::Packet::TCP->new(dst => 22);
-
-   #Assemble frame
-   #It will also open a Net::Packet::DescL3 descriptor
-   # and a Net::Packet::Dump object
-   my $frame = Net::Packet::Frame->new(l3 => $ip, l4 => $tcp);
-
-   $frame->send;
-
-   #Print the reply just when it has been received
-   until ($Env->dump->timeout) {
-      if ($frame->recv) {
-         print $frame->reply->l3, "\n";
-         print $frame->reply->l4, "\n";
-         last;
-      }
-   }
-
 =head1 DESCRIPTION
 
 This module is a unified framework to craft, send and receive packets at layers 2, 3, 4 and 7.
 
-Basically, you forge each layer of a frame (Net::Packet::IPv4 for layer 3, Net::Packet::TCP for layer 4 ; for example), and pack all of this into a Net::Packet::Frame object. Then, you can send the frame to the network, and receive it easily, since the response is automatically searched for and matched against the request.
+Basically, you forge each layer of a frame (B<Net::Packet::IPv4> for layer 3, B<Net::Packet::TCP> for layer 4; for example), and pack all of this into a B<Net::Packet::Frame> object. Then, you can send the frame to the network, and receive its response easily, because the response is automatically searched for and matched against the request.
 
-If you want some layer 2, 3 or 4 protocol encoding/decoding to be added, just ask, and give a corresponding .pcap file ;)
+If you want some layer 2, 3 or 4 protocol encoding/decoding to be added, just ask, and give a corresponding .pcap file ;). You can also subscribe to netpacket-sers@gomor.org by sumply sending an e-mail requesting for it.
 
 You should study various pod found in all classes, example files found in B<examples> directory that come with this tarball, and also tests in B<t> directory.
 
